###Install and load packages (version numbers next to package)
library(manifestoR) #1.5.0
library(dplyr) #1.0.7
library(data.table) #1.14.0
library(varhandle) #2.0.5

###Get api key and set manifesto project version number (please do not change)
manifesto_api_key_file <- "manifesto_apikey.txt"
datasetversion <- "2019b"

###Download manifesto dataset in version 2019b
mp_setapikey(manifesto_api_key_file)
manifesto <- mp_maindataset(version = datasetversion)

###Adding manifesto ID variable
manifesto <- mutate(manifesto, manifesto_id = paste0(as.character(party),"_", as.character(edate)))

###Add additional entries from CW's data
cmp_data_unique <- read.csv2("new_entries.csv", fileEncoding = "UTF-8")
manifesto <- subset(manifesto, select = -c(id_perm, datasetversion, per608_3, per607_3, per607_1, per606_1, per605_1, per602_1, per601_2, per601_1, per305_5, per305_3, per305_2, per202_4, per202_3, per416_1, per201_2, per201_1, per305_1, per103_1, per608_2, per202_2, per305_4, per608_1, per605_2, partyabbrev, per202_1, per703_1, corpusversion, per606_2, per607_2, per305_6, per703_2, per602_2, per416_2, testeditsim, per103_2))
manifesto <- rbind(manifesto, cmp_data_unique)

###Drop observations in manifesto dataset not included in CW's data
drop <- read.csv2("drop.csv", fileEncoding = "UTF-8")
manifesto <- manifesto[ ! manifesto$manifesto_id %in% drop$manifesto_id, ]

###Change values between datasets (currently partyname, absseat and totseat)
differences <- read.csv2("differences.csv", fileEncoding = "UTF-8")
setDT(manifesto)

#partyname changes
differences_partyname <- subset(differences, var == "partyname")
setDT(differences_partyname)
manifesto[differences_partyname, on = .(manifesto_id), `:=` (partyname = values.wratil)]

#absseat changes
differences_absseat <- subset(differences, var == "absseat")
setDT(differences_absseat)
differences_absseat<- differences_absseat[, values.wratil:=as.numeric(values.wratil)]
manifesto[differences_absseat, on = .(manifesto_id), `:=` (absseat = values.wratil)]

#totseat changes
differences_totseat <- subset(differences, var == "totseat")
setDT(differences_totseat)
differences_totseat <- differences_totseat[, values.wratil:=as.numeric(values.wratil)]
manifesto[differences_totseat, on = .(manifesto_id), `:=` (totseat = values.wratil)]

###Output of final dataset
write.csv(manifesto,"cmp_data_modified.csv", fileEncoding = "UTF-8", na="")






